@@ -4,13 +4,16 @@ from typing import List, Tuple
 
 import numpy as np
 from dask import delayed
+from scipy.ndimage import gaussian_filter
 from scipy.ndimage.morphology import binary_fill_holes
 from scipy.sparse import csr_matrix
 from scipy.sparse.csgraph import connected_components as connected_components_graph
 from skimage import measure
+from skimage.feature import peak_local_max
 
 from cidan.LSSC.functions.embeddings import embedEigenSqrdNorm
 from cidan.LSSC.functions.progress_bar import printProgressBarROI
+from cidan.LSSC.functions.widefield_functions import *
 
 
 @delayed
@@ -21,10 +24,12 @@ def roi_extract_image(*, e_vectors: np.ndarray,
                       elbow_threshold_method: bool, elbow_threshold_value: float,
                       eigen_threshold_method: bool,
                       eigen_threshold_value: float, merge_temporal_coef: float,
-                      roi_size_limit: int, box_num: int, total_num_spatial_boxes=0,
+                      roi_size_limit: int, box_num: int, roi_eccentricity_limit: float, total_num_spatial_boxes=0,
                       total_num_time_steps=0, save_dir=0, print_progress=False,
                       initial_pixel=-1,
-                      print_info=True, progress_signal=None) -> List[
+
+                      print_info=True, progress_signal=None, wide_field=False,
+                      mask=None, local_max_method=False) -> List[
     np.ndarray]:
     """
     Computes the Local Selective Spectral roi_extraction algorithm on an set of
@@ -35,6 +40,8 @@ def roi_extract_image(*, e_vectors: np.ndarray,
         Eigen vector in 2D numpy array
     original_shape
         Original shape of image
+        Original
+        shape of image
     original_2d_vol
         A flattened 2d volume of the original image, used for mergestep
     num_rois
@@ -74,17 +81,38 @@ def roi_extract_image(*, e_vectors: np.ndarray,
                           np.array  of pixels roi 2] ... ]
     It will have length num_rois unless max_iter amount is surpassed
     """
+    from CIDAN.LSSC.functions.data_manipulation import cord_2d_to_pixel_num
+
     # if print_info:
     #     print("Spatial Box {}: Starting ROI selection process".format(box_num))
     pixel_length = e_vectors.shape[0]
     if len(original_shape) == 2:
         original_shape = (1, original_shape[0], original_shape[1])
+
     pixel_embedings = embedEigenSqrdNorm(
         e_vectors)  # embeds the pixels in the eigen space
-    initial_pixel_list = np.flip(np.argsort(
-        pixel_embedings))  # creates a list of pixels with the highest values
+
+    if local_max_method or wide_field:
+
+        image = np.reshape(pixel_embedings, original_shape[1:])
+        image = gaussian_filter(image, np.std(image))
+        local_max = peak_local_max(image, min_distance=int(
+            roi_size_min * .25) if roi_size_min * .25 > 5 else 5)
+
+        initial_pixel_list = cord_2d_to_pixel_num(local_max.transpose(),
+                                                  original_shape[1:])
+        sort_ind = np.flip(np.argsort(pixel_embedings[initial_pixel_list]))
+        initial_pixel_list = initial_pixel_list[sort_ind]
+        print(len(initial_pixel_list))
+        # if num_rois!=60:
+        #     return [np.array([int(x)]) for x in initial_pixel_list]
+        unassigned_pixels = np.arange(0, pixel_length, 1, dtype=int)
+    else:
+        initial_pixel_list = np.flip(np.argsort(
+            pixel_embedings))  # creates a list of pixels with the highest values
     # in the eigenspace this list is used to decide on the initial point
     # for the roi
+
     if initial_pixel != -1:
         initial_pixel_list = np.array([initial_pixel])
     roi_list = []  # output list of rois
@@ -93,8 +121,10 @@ def roi_extract_image(*, e_vectors: np.ndarray,
     # from initial_pixel_list
     iter_counter = 0
     total_counter = 0
+    pixels_assigned_set = {}
     while len(roi_list) < num_rois and len(
-            initial_pixel_list) > 0 and iter_counter < max_iter:
+            initial_pixel_list) > 0 and iter_counter < max_iter and (
+            not wide_field or float(len(pixels_assigned_set)) / pixel_length > .95):
         iter_counter += 1
         total_counter += 1
         # print(iter_counter, len(roi_list.json),
@@ -121,16 +151,28 @@ def roi_extract_image(*, e_vectors: np.ndarray,
         # selects pixels in roi
         pixels_in_roi = np.nonzero(
             small_pixel_distance <= small_pixel_embeding_norm)[0]
+        if wide_field:
+            # runs a connected component analysis around the initial point
+            # in original image
+            pixels_in_roi_comp = connected_component(pixel_length,
+                                                     original_shape,
+                                                     mask_to_data_point(
+                                                         pixels_in_roi, mask,
+                                                         original_shape),
+                                                     mask_to_data_point(
+                                                         initial_pixel, mask,
+                                                         original_shape), )
 
-        # runs a connected component analysis around the initial point
-        # in original image
-        pixels_in_roi_comp = connected_component(pixel_length,
-                                                 original_shape,
-                                                 pixels_in_roi,
-                                                 initial_pixel)
-
-        pixels_in_roi_final = pixels_in_roi_comp
+            pixels_in_roi_final = pixels_in_roi_comp
+        else:
+            # runs a connected component analysis around the initial point
+            # in original image
+            pixels_in_roi_comp = connected_component(pixel_length,
+                                                     original_shape,
+                                                     pixels_in_roi,
+                                                     initial_pixel)
 
+            pixels_in_roi_final = pixels_in_roi_comp
         # runs refinement step if enabled and if enough pixels in roi
         if refinement:  # TODO Look at this again
             # and len(pixels_in_roi_final) > \
@@ -170,38 +212,68 @@ def roi_extract_image(*, e_vectors: np.ndarray,
 
             # runs a connected component analysis around the initial point
             # in original image
-            rf_pixels_in_roi_comp = connected_component(pixel_length,
-                                                        original_shape,
-                                                        rf_pixels_in_roi,
-                                                        rf_initial_point)
-            rf_pixels_in_roi_filled = \
-                fill_holes_func([rf_pixels_in_roi_comp], pixel_length, original_shape)[
-                    0]
-            pixels_in_roi_final = rf_pixels_in_roi_filled
+            if wide_field:
+                rf_pixels_in_roi_comp = connected_component(pixel_length,
+                                                            original_shape,
+                                                            mask_to_data_point(
+                                                                rf_pixels_in_roi, mask,
+                                                                original_shape),
+                                                            mask_to_data_point(
+                                                                rf_initial_point, mask,
+                                                                original_shape))
+                rf_pixels_in_roi_filled = \
+                    fill_holes_func([rf_pixels_in_roi_comp], pixel_length,
+                                    original_shape)[
+                        0]  # TODO do we fill the rois in widefield
+                pixels_in_roi_final = rf_pixels_in_roi_filled
+
+            else:
+                rf_pixels_in_roi_comp = connected_component(pixel_length,
+                                                            original_shape,
+                                                            rf_pixels_in_roi,
+                                                            rf_initial_point)
+                rf_pixels_in_roi_filled = \
+                    fill_holes_func([rf_pixels_in_roi_comp], pixel_length,
+                                    original_shape)[
+                        0]
+                pixels_in_roi_final = rf_pixels_in_roi_filled
 
         # checks if roi is big enough
         # print("roi size:", len(pixels_in_roi_final))
         # print("iter counter: ", iter_counter)
         # print( len(
         #         pixels_in_roi_final))
-        if roi_size_min < len(
-                pixels_in_roi_final) < roi_size_limit:
+
+        if wide_field or (roi_size_min < len(
+                pixels_in_roi_final) < roi_size_limit and roi_eccentricity(pixel_length,
+                                                                           original_shape,
+                                                                           pixels_in_roi_final) <= roi_eccentricity_limit):
+
             roi_list.append(pixels_in_roi_final)
+
             iter_counter = 0
-            # takes all pixels in current roi out of initial_pixel_list
-            initial_pixel_list = np.extract(
-                np.in1d(initial_pixel_list, pixels_in_roi_final,
-                        assume_unique=True, invert=True),
-                initial_pixel_list)
-            if initial_pixel not in pixels_in_roi_final:
+            if wide_field:
                 initial_pixel_list = np.delete(initial_pixel_list, 0)
 
+            else:
+
+                # takes all pixels in current roi out of initial_pixel_list
+                initial_pixel_list = np.extract(
+                    np.in1d(initial_pixel_list, pixels_in_roi_final,
+                            assume_unique=True, invert=True),
+                    initial_pixel_list)
+                if initial_pixel not in pixels_in_roi_final:
+                    initial_pixel_list = np.delete(initial_pixel_list, 0)
+
             # print(len(initial_pixel_list))
         else:
-            # takes current initial point and moves it to end of
-            # initial_pixel_list
-            initial_pixel_list = np.delete(
-                np.append(initial_pixel_list, initial_pixel_list[0]), 0)
+            if wide_field:
+                initial_pixel_list = np.delete(initial_pixel_list, 0)
+            else:
+                # takes current initial point and moves it to end of
+                # initial_pixel_list
+                initial_pixel_list = np.delete(
+                    np.append(initial_pixel_list, initial_pixel_list[0]), 0)
     if fill_holes:
         # TODO combine into connected component function
         roi_list = fill_holes_func(roi_list, pixel_length, original_shape)
@@ -209,9 +281,17 @@ def roi_extract_image(*, e_vectors: np.ndarray,
     if merge:
         roi_list = merge_rois(roi_list,
                               temporal_coefficient=merge_temporal_coef,
-                              original_2d_vol=original_2d_vol)
+                              original_2d_vol=original_2d_vol, roi_eccentricity_limit=roi_eccentricity_limit)
         if fill_holes:
             roi_list = fill_holes_func(roi_list, pixel_length, original_shape)
+    if wide_field:
+        # handles overlapping rois
+        roi_list = remove_overlap_widefield(roi_list, mask, original_shape, e_vectors)
+    new_rois_filtered= []
+    for roi in roi_list:
+        if roi_eccentricity(pixel_length,original_shape,roi)<=roi_eccentricity_limit:
+            new_rois_filtered.append(roi)
+    roi_list=new_rois_filtered
     # print("Went through " + str(total_counter) + " iterations")
     if print_progress:
         with open(os.path.join(save_dir, "temp_files/rois/s_%s" % str(box_num)),
@@ -222,6 +302,32 @@ def roi_extract_image(*, e_vectors: np.ndarray,
     return roi_list
 
 
+def remove_overlap_widefield(roi_list, mask, original_shape, e_vectors):
+    """
+    Removes overlapping pixels in widefield.
+    Parameters
+    ----------
+    roi_list
+    mask
+    original_shape
+    e_vectors
+
+    Returns
+    -------
+
+    """
+
+    A = np.zeros([original_shape[1] * original_shape[2], len(roi_list)], dtype=bool)
+    for num, roi in enumerate(roi_list):
+        A[roi, num] = True
+    A_graph = np.matmul(A.transpose(), A)
+    A_graph_sum = np.sum(A_graph, axis=1)
+    row_numbers = np.arange(0, original_shape[1] * original_shape[2], 1)
+    rows_with_multiple = row_numbers[A_graph_sum > 1]
+    for x in list(rows_with_multiple):
+        row = A_graph[x, :]
+
+
 def fill_holes_func(roi_list: List[np.ndarray], pixel_length: int,
                     original_shape: Tuple[int, int, int]) -> List[np.ndarray]:
     """
@@ -331,6 +437,32 @@ def connected_component(pixel_length: int, original_shape: Tuple[int, int, int],
     pixels_in_roi_new = np.nonzero(
         blobs_labels == correct_label)[0]
     return pixels_in_roi_new
+def roi_eccentricity(pixel_length: int, original_shape: Tuple[int, int, int],
+                        pixels_in_roi: np.ndarray) -> np.ndarray:
+    """
+    Runs a eccentricity analysis on a group of pixels in an image
+    Parameters
+    ----------
+    pixel_length
+        Number of pixels in image
+    original_shape
+        the original shape of image
+    pixels_in_roi
+        A list of pixels in the roi
+
+
+
+    Returns
+    -------
+    Eccentricity of roi, with 0 being circle 1 being a line
+    """
+    # TODO add in im fill before connected component
+    # first creates an image with pixel values of 1 if pixel in roi
+    original_zeros = np.zeros(pixel_length, dtype=int)
+    original_zeros[pixels_in_roi] = 1
+    pixel_image = np.reshape(original_zeros, original_shape[1:])
+    eccentricity = measure.regionprops(pixel_image)[0]["eccentricity"]
+    return eccentricity
 
 
 def select_eigen_vectors(eigen_vectors: np.ndarray,
@@ -450,7 +582,7 @@ def elbow_threshold(pixel_vals: np.ndarray, pixel_val_sort_indices: np.ndarray,
 
 
 def merge_rois(roi_list: List,
-               temporal_coefficient: float, original_2d_vol: np.ndarray):
+               temporal_coefficient: float, original_2d_vol: np.ndarray, roi_eccentricity_limit=1.0):
     # TODO is this the most efficient implementation I can do
     """
     Merges rois based on temporal and spacial overlap
@@ -499,7 +631,7 @@ def merge_rois(roi_list: List,
                 rois_to_merge = []
                 for num, roi in group_zipped:
                     if compare_time_traces(timetrace_first,
-                                           timetraces[num]) > temporal_coefficient:
+                                           timetraces[num]) > temporal_coefficient and any([x in roi for x in first_roi]):
                         rois_to_merge.append(num)
                 first_roi = list(reduce(combine_rois,
                                         [first_roi] + [group_zipped[x][1] for x in
