@@ -36,7 +36,8 @@ def process_data(*, num_threads: int, test_images: bool, test_output_dir: str,
                  eigen_threshold_method: bool,
                  eigen_threshold_value: float, merge_temporal_coef: float,
                  roi_size_max: int, pca: bool, pca_data: np.ndarray,
-                 eigen_accuracy: int, progress_signal=None):
+                 eigen_accuracy: int, roi_eccentricity_limit: float,
+                 local_max_method: bool, progress_signal=None):
     logger1.debug("""Inputs: num_threads {0},test_images {1}, test_output_dir {2},
                  save_dir {3}, save_intermediate_steps {4},
                  load_data {5}, data_path {6},
@@ -109,7 +110,8 @@ def process_data(*, num_threads: int, test_images: bool, test_output_dir: str,
     all_rois = []
     all_boxes_eigen_vectors = []
     for spatial_box in spatial_boxes:
-        spatial_box_data_list = [spatial_box.extract_box(x) for x in image_data]
+        spatial_box_data_list = [convert_to_float(spatial_box.extract_box(x)) for x in
+                                 image_data]
         if pca:
             spatial_box_data_list_pca = [spatial_box.extract_box(x) for x in pca_data]
         if len(spatial_box_data_list) == 1:
@@ -174,7 +176,7 @@ def process_data(*, num_threads: int, test_images: bool, test_output_dir: str,
                                                      save_dir=save_dir,
                                                      total=total_num_time_steps * total_num_spatial_boxes)
 
-                all_eigen_vectors_list.append(eigen_vectors)
+                all_eigen_vectors_list.append(eigen_vectors.compute())
                 if test_images:
                     pass
                     # delayed(save_eigen_images)(eigen_vectors=eigen_vectors,
@@ -216,7 +218,9 @@ def process_data(*, num_threads: int, test_images: bool, test_output_dir: str,
                                  box_num=spatial_box.box_num, print_progress=True,
                                  total_num_time_steps=total_num_time_steps,
                                  total_num_spatial_boxes=total_num_spatial_boxes,
-                                 save_dir=save_dir, progress_signal=progress_signal)
+                                 roi_eccentricity_limit=roi_eccentricity_limit,
+                                 save_dir=save_dir, local_max_method=local_max_method,
+                                 progress_signal=progress_signal)
         if test_images:
             pass
             # delayed(save_roi_images)(
@@ -301,3 +305,8 @@ if __name__ == '__main__':
 @delayed
 def sliceData(data, start_end):
     return data[0][start_end[0]:start_end[1], :, :]
+
+
+@delayed
+def convert_to_float(data):
+    return data.astype(np.float32)
