@@ -1,7 +1,7 @@
 import numpy as np
 
 
-def calculateMeanTrace(roi_data, neuropil_data, roi_denoised_data, denoise=True,
+def calculateMeanTrace(roi_data, neuropil_data,
                        sub_neuropil=False):
     """
     Calcualtes the mean time trace for a given roi and data
@@ -14,14 +14,14 @@ def calculateMeanTrace(roi_data, neuropil_data, roi_denoised_data, denoise=True,
     -------
     A 1d nd array with the time trace for the ROI
     """
-    if denoise:
-        roi_data = roi_denoised_data
+
     mean = np.mean(roi_data, axis=0)
     if sub_neuropil:
         mean = mean - np.mean(neuropil_data, axis=0)
-
+    # if denoise:
+    #     mean = waveletDenoise(mean)
     return mean
 
 
-def neuropil(roi_data, neuropil_data, roi_denoised_data):
+def neuropil(roi_data, neuropil_data, ):
     return np.mean(neuropil_data, axis=0)
